SystemOrganization addCategory: #'Versionner-Tests-Core-Model'!

TestCase subclass: #MBAbstractTest
	instanceVariableNames: 'configuration'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Tests-Core-Model'!

!MBAbstractTest class methodsFor: 'testing' stamp: 'topa 4/15/2011 09:50'!
isAbstract
	"Override to true if a TestCase subclass is Abstract and should not have
	TestCase instances built from it"
	
	^ self name = #MBAbstractTest! !

!MBAbstractTest methodsFor: 'accessing' stamp: 'dkh 2/23/2011 15:19'!
configurationName

	^'ConfigurationOfDummyConfiguration'! !

!MBAbstractTest methodsFor: 'util' stamp: 'dkh 2/23/2011 15:17'!
removeClassIfExist: aSymbol
	Smalltalk globals at: aSymbol ifPresent: [ :cls | cls removeFromSystem ]! !

!MBAbstractTest methodsFor: 'running' stamp: 'dkh 2/23/2011 21:17'!
setUp

	(Smalltalk globals includesKey: self configurationName asSymbol) 
		ifFalse: [ 
			MetacelloToolBox configurationNamed: self configurationName.
				(Smalltalk globals at: self configurationName asSymbol) compile: 'baseline10: spec 
        <version: ''1.0-baseline''>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec repository: ''http://www.squeaksource.com/Versionner''.
		    spec package: ''Collections-Streams''.
                ].'.

			(Smalltalk globals at: self configurationName asSymbol) compile: 'default: spec 
        <version: ''default''>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec repository: ''http://www.squeaksource.com/Versionner''.
		    spec package: ''Collections-Streams''.
                ].'.
			].
		
	configuration := (Smalltalk globals at: self configurationName asSymbol) 
! !

!MBAbstractTest methodsFor: 'running' stamp: 'dkh 2/23/2011 15:24'!
tearDown
	super tearDown.
	configuration := nil.
	self removeClassIfExist: self configurationName asSymbol
! !

MBAbstractTest subclass: #MBInfoTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Tests-Core-Model'!

MBInfoTest subclass: #MBAbstractVersionInfoTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Tests-Core-Model'!

!MBAbstractVersionInfoTest class methodsFor: 'testing' stamp: 'topa 4/15/2011 14:58'!
isAbstract
	"Override to true if a TestCase subclass is Abstract and should not have
	TestCase instances built from it"
	
	^ self name = #MBAbstractVersionInfoTest! !

MBAbstractVersionInfoTest subclass: #MBBaselineInfoTest
	instanceVariableNames: 'info browser'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Tests-Core-Model'!

!MBBaselineInfoTest methodsFor: 'running' stamp: 'dkh 4/18/2011 20:22'!
expectedFailures 
	true ifTrue: [ ^#() ].
	^ #(#testcalculateInfoList)! !

!MBBaselineInfoTest methodsFor: 'running' stamp: 'dkh 3/6/2011 20:33'!
setUp
	| configurationInfo |
	super setUp.
	configurationInfo := MBConfigurationInfo configurationClass: configuration.
	info := configurationInfo baselines detect: [:inf | inf version versionString = '1.0-baseline']
! !

!MBBaselineInfoTest methodsFor: 'tests' stamp: 'AlexandreBergel 4/15/2011 09:24'!
testCommand
	| configurationInfo baselineInfo |
	configurationInfo := MBConfigurationInfo configurationClass: configuration.
	baselineInfo := configurationInfo baselines detect: [:inf | inf version versionString = '1.0-baseline'].
	self assert: ((baselineInfo commands) 
						includesAllOf: {MBAddBaselineCommand . MBSaveAllPackagesAndAddVersionCommand})  ! !

!MBBaselineInfoTest methodsFor: 'tests' stamp: 'DaleHenrichs 03/08/2011 13:49'!
testCopyBaseline
	| configurationInfo baselineInfo |
	configurationInfo := MBConfigurationInfo configurationClass: configuration.
	baselineInfo := configurationInfo baselines detect: [:inf | inf version versionString = '1.0-baseline'].
	self assert: (baselineInfo isKindOf: MBBaselineInfo).

	[  (MBCopyBaselineCommand target: baselineInfo for: browser) copyBaselineWithNumber: '1.1'] 
		valueSupplyingAnswer: 'this is my comment'.
 
	self assert: (configuration compiledMethodAt: #baseline11: ifAbsent: []) notNil.
	self assert: (configuration sourceCodeAt: #baseline11:) =   'baseline11: spec
	<version: ''1.1-baseline''>

	spec for: #''common'' do: [
		spec blessing: #''baseline''.
		spec description: ''this is my comment''.
		spec repository: ''http://www.squeaksource.com/Versionner''.
		spec package: ''Collections-Streams''. ].
'! !

!MBBaselineInfoTest methodsFor: 'tests' stamp: 'dkh 3/19/2011 10:42'!
testInstantiation
	|  configurationInfo baseline |

	self should: [ MBBaselineInfo new ] raise: Error.
	self 
		shouldnt: [	configurationInfo := MBConfigurationInfo configurationClass: configuration.
	baseline := configurationInfo baselines detect: [:inf | inf version versionString = '1.0-baseline'].
] 
		raise: Error.
	
	self assert: (baseline versionString = '1.0-baseline').
	self assert: (info configurationInfo configurationClass == (Smalltalk at: #ConfigurationOfDummyConfiguration))! !

!MBBaselineInfoTest methodsFor: 'tests' stamp: 'TesterBob 3/28/2011 00:19'!
testcalculateInfoList

	info := (MBBaselineInfo version: (MBVersionInfo version: (MetacelloVersion fromString: '1.0-baseline')))
		configurationInfo: (MBConfigurationInfo configurationClass: configuration).
		
	info calculateInfoList! !

MBInfoTest subclass: #MBConfigurationInfoTest
	instanceVariableNames: 'info browser'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Tests-Core-Model'!

!MBConfigurationInfoTest methodsFor: 'running' stamp: 'dkh 3/4/2011 14:13'!
setUp
	super setUp.

	info := MBConfigurationInfo configurationClass: configuration.
! !

!MBConfigurationInfoTest methodsFor: 'tests' stamp: 'dkh 3/6/2011 14:56'!
testBaselines

	"+1 is for the default: baseline"
	self assert: info baselines size = ((configuration selectors select: [ :s | s beginsWith: 'baseline']) size + 1).
! !

!MBConfigurationInfoTest methodsFor: 'tests' stamp: 'dkh 3/6/2011 14:56'!
testDefaultVersion
	
	self assert: info baselines size = 
					((configuration selectors select: [ :s | s beginsWith: 'baseline']) size + 1).
! !

!MBConfigurationInfoTest methodsFor: 'tests' stamp: 'dkh 3/2/2011 08:00'!
testInitialization
	| conf |
	self should: [ MBConfigurationInfo new ] raise: Error.
	self shouldnt: [ conf := MBConfigurationInfo configurationClass: ConfigurationOfVersionner ] raise: Error.
	self assert: conf name = 'ConfigurationOfVersionner'! !

!MBInfoTest methodsFor: 'tests' stamp: 'dkh 3/2/2011 07:58'!
testIsDirty
	"info is not dirty per default"
	self deny: MBInfo new isDirty! !

!MBInfoTest methodsFor: 'tests' stamp: 'dkh 3/4/2011 14:15'!
testName
	| info |
	info := MBInfo new.
	self assert: (info name isNil).

	info name: 'foobar'.
	self assert: (info name = 'foobar').
	self assert: (info printString = 'foobar').

! !

!MBInfoTest methodsFor: 'tests' stamp: 'AlexandreBergel 3/27/2011 11:58'!
testvalidationIcon

	| mbInfo |
	self assert: (MBInfo new validationIcon isForm).
	
	mbInfo := MBInfo new.
	mbInfo validate.
	self assert: (mbInfo validationIcon isForm).
	
	! !

!MBInfoTest methodsFor: 'tests' stamp: 'AlexandreBergel 3/27/2011 11:58'!
testvalidationIconSymbol

	| mbInfo |
	self assert: (MBInfo new validationIconSymbol isSymbol).
	
	mbInfo := MBInfo new.
	mbInfo validate.
	self assert: (mbInfo validationIconSymbol isSymbol).
	
	! !

MBInfoTest subclass: #MBPackageInfoTest
	instanceVariableNames: 'package browser'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Tests-Core-Model'!

!MBPackageInfoTest methodsFor: 'running' stamp: 'dkh 3/2/2011 08:03'!
setUp
"	(Smalltalk includesKey: #TMPClass)
		ifTrue: [ (Smalltalk at: #TMPClass) removeFromSystem ].
"		
"	Smalltalk organization removeCategory: 'FooBarZork'."
	(MCPackage named: 'FooBarZork') unload.
	PackageOrganizer default unregisterPackageNamed: 'FooBarZork'.

	package := MBPackageInfo named: 'FooBarZork'.! !

!MBPackageInfoTest methodsFor: 'running' stamp: 'AlexandreBergel 1/16/2011 21:06'!
tearDown
"	(Smalltalk includesKey: #TMPClass)
		ifTrue: [ (Smalltalk at: #TMPClass) removeFromSystem ].
"! !

!MBPackageInfoTest methodsFor: 'tests' stamp: 'dkh 3/2/2011 08:03'!
testInstantiation
	self should: [ MBPackageInfo new ] raise: Error.

	self should: [ MBPackageInfo named: #'FooBar' ] raise: AssertionFailure.
	self shouldnt: [ MBPackageInfo named: 'FooBar' ] raise: Error.! !

!MBPackageInfoTest methodsFor: 'tests' stamp: 'dkh 2/23/2011 21:19'!
testIsDirty
	"This test is likely to be bogus ... cannot just create a package for packages that don'e exist. see Metacello Issue 113"
	
	| workingCopy cls |
	self deny: (package isDirty).
	self assert: (package printString =  'FooBarZork ---').
	
	"We create a class"		
	self deny: (Smalltalk includesKey: #TMPClass).
	cls := Object subclass: #TMPClass
		instanceVariableNames: ''
		classVariableNames: ''
		poolDictionaries: ''
		category: 'FooBarZork'.
		
	self deny: (package isDirty).
	self assert: (package printString =  'FooBarZork ---').

	(Smalltalk includesKey: #TMPClass)
		ifTrue: [ (Smalltalk at: #TMPClass) removeFromSystem ].
! !

!MBPackageInfoTest methodsFor: 'tests' stamp: 'dkh 2/23/2011 21:22'!
testPrintOn
	self assert: (package printString =  'FooBarZork ---').! !

!MBPackageInfoTest methodsFor: 'tests' stamp: 'DaleHenrichs 03/08/2011 13:41'!
testWorkingCopy

	| orga workingCopy |
	self assert: (PackageOrganizer default packageNamed: 'FooBarZork' ifAbsent: []) isNil.	
	package := MBPackageInfo named: 'FooBarZork'.
	workingCopy := package workingCopy.
	"creating a packageInfo for a package that is not currently loaded can create problems. see Metacello Issue 113"
	self assert: workingCopy isNil.
! !

MBAbstractTest subclass: #MBSpecInfoTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Tests-Core-Model'!

MBSpecInfoTest subclass: #MBGroupInfoTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Tests-Core-Model'!

!MBGroupInfoTest methodsFor: 'tests' stamp: 'AlexandreBergel 3/27/2011 12:11'!
testPrintOn
	| str | 
	self shouldnt: [str := MBGroupInfo new printString] raise: Error.
	self assert: (str = 'nil ---').
	
! !

!MBGroupInfoTest methodsFor: 'tests' stamp: 'AlexandreBergel 3/27/2011 12:11'!
testgroupContentsIfLoaded

	self assert: MBGroupInfo new groupContentsIfLoaded isEmpty! !

!MBSpecInfoTest class methodsFor: 'testing' stamp: 'topa 4/15/2011 09:50'!
isAbstract
	"Override to true if a TestCase subclass is Abstract and should not have
	TestCase instances built from it"
	
	^ self name = #MBSpecInfoTest! !

TestCase subclass: #MBConfigurationBranchTest
	instanceVariableNames: 'gofer configurationRoot'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Tests-Core-Model'!

!MBConfigurationBranchTest methodsFor: 'running' stamp: 'dkh 4/17/2011 12:41'!
hasPackage: aString
	| package |
	package := MCWorkingCopy allManagers
		detect: [ :each | each packageName = aString ]
		ifNone: [ nil ].
	^ package notNil! !

!MBConfigurationBranchTest methodsFor: 'running' stamp: 'dkh 4/17/2011 12:28'!
setUp

	| repo |
	super setUp.
	gofer := Gofer new.
	gofer disablePackageCache.
	repo := MBMonticelloPackagesResource current monticelloRepository.
	gofer repository: repo.
	Smalltalk at: #'MB_Foo_Test_Repository' put: repo.
	configurationRoot := MBConfigurationRoot new.
	configurationRoot register.
	! !

!MBConfigurationBranchTest methodsFor: 'running' stamp: 'dkh 4/17/2011 12:28'!
tearDown
	configurationRoot ifNotNil: [ configurationRoot unregister ].
	Smalltalk removeKey: #'MB_Foo_Test_Repository' ifAbsent: [].
	gofer := Gofer new.
	self tearDownPackages do: [:pkgName | (self hasPackage: pkgName) ifTrue: [ gofer package: pkgName ]].
	gofer references notEmpty ifTrue: [ gofer unload ].
! !

!MBConfigurationBranchTest methodsFor: 'running' stamp: 'dkh 4/17/2011 12:53'!
tearDownPackages

	^#('MBFooTests' 'ConfigurationOfMBBranchTests')! !

!MBConfigurationBranchTest methodsFor: 'tests' stamp: 'dkh 4/17/2011 12:48'!
test0010BasicLoad
	"
		- make sure that the configuration can be loaded without error
		- make sure that version 1.0 can be loaded without error"
	
	configurationRoot unregister.
	self assert: (Smalltalk at: #ConfigurationOfMBBranchTests ifAbsent: []) isNil.
	gofer version: 'ConfigurationOfMBBranchTests-dkh.1'.
	gofer load.
	((Smalltalk at: #ConfigurationOfMBBranchTests) project version: '1.0') load.
	self assert: (Smalltalk at: #MBFooTestA ifAbsent: []) notNil
! !

!MBConfigurationBranchTest methodsFor: 'tests' stamp: 'dkh 4/17/2011 12:48'!
test0011BasicLoad
	"
		- make sure that the branch configuration can be loaded without error
		- make sure that version 1.0 can be loaded without error"
	
	configurationRoot unregister.
	self assert: (Smalltalk at: #ConfigurationOfMBBranchTests ifAbsent: []) isNil.
	gofer version: 'ConfigurationOfMBBranchTests.branch-dkh.2'.
	gofer load.
	((Smalltalk at: #ConfigurationOfMBBranchTests) project version: '1.0') load.
	self assert: (Smalltalk at: #MBFooTestA ifAbsent: []) notNil
! !

!MBConfigurationBranchTest methodsFor: 'tests' stamp: 'dkh 4/17/2011 13:13'!
test002ConfigurationReferences
	"Make sure that the project and project branches show up in configuration references (for load configuration command)"

	| referenceMap |
	referenceMap := MBLoadConfigurationCommand new configurationReferencesFrom: MBMonticelloPackagesResource current monticelloRepository.
	self assert: (referenceMap keys includes: 'ConfigurationOfMBBranchTests.branch')! !

TestCase subclass: #MBConfigurationRootTest
	instanceVariableNames: 'gofer configurationRoot'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Tests-Core-Model'!

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 4/18/2011 20:22'!
expectedFailures 
	true ifTrue: [ ^#() ].
	^ #(
		test0031ConfigurationInfoChanged
"		test0040BasicVersionLoad 
		test0050BasicVersionLoad
		test0060BasicVersionLoad
		test0061ConfigurationInfoChanged
		test0070BasicVersionLoad
		test0080BasicVersionLoad
		test0081BasicVersionLoad
		test0082ConfigurationInfoChanged
		test0090BasicVersionLoad
"	) "change tracking issue"! !

!MBConfigurationRootTest methodsFor: 'running' stamp: 'dkh 4/17/2011 14:50'!
hasPackage: aString
	| package |
	package := MCWorkingCopy allManagers
		detect: [ :each | each packageName = aString ]
		ifNone: [ nil ].
	^ package notNil! !

!MBConfigurationRootTest methodsFor: 'scenarios' stamp: 'dkh 3/18/2011 19:00'!
scenariosForTests
	"
	1. select a configuration, then unload the configuration ... in OB you gtt an error because the 
		project was undefined .... simulate by creating a ConfigurationOf class that is not a real configuration
	2. add new configuration should associate the chosen repository with the configuration, too...maybe 
		addConfigurationTest should check this
	3. add new configuration then do checkpoing dev and note that dirty * is still on the label in the browser
	"! !

!MBConfigurationRootTest methodsFor: 'running' stamp: 'dkh 3/9/2011 17:24'!
setUp

	| repo |
	super setUp.
	gofer := Gofer new.
	gofer disablePackageCache.
	repo := MBMonticelloPackagesResource current monticelloRepository.
	gofer repository: repo.
	Smalltalk at: #'MB_Foo_Test_Repository' put: repo.
	configurationRoot := MBConfigurationRoot new.
	configurationRoot register.
	! !

!MBConfigurationRootTest methodsFor: 'running' stamp: 'dkh 3/9/2011 17:28'!
tearDown
	configurationRoot ifNotNil: [ configurationRoot unregister ].
	Smalltalk removeKey: #'MB_Foo_Test_Repository' ifAbsent: [].
	gofer := Gofer new.
	self tearDownPackages do: [:pkgName | (self hasPackage: pkgName) ifTrue: [ gofer package: pkgName ]].
	gofer references notEmpty ifTrue: [ gofer unload ].
! !

!MBConfigurationRootTest methodsFor: 'running' stamp: 'dkh 3/9/2011 17:34'!
tearDownPackages

	^#('MBFooTests' 'ConfigurationOfMBFooTests')! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 3/10/2011 08:08'!
test0010BasicLoad
	"First test: 
		- make sure that the configuration can be loaded without error
		- make sure that version 1.0 can be loaded without error"
	
	configurationRoot unregister.
	self assert: (Smalltalk at: #ConfigurationOfMBFooTests ifAbsent: []) isNil.
	gofer version: 'ConfigurationOfMBFooTests-dkh.1'.
	gofer load.
	((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.0') load.
	self assert: (Smalltalk at: #MBFooTestA ifAbsent: []) notNil
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 4/4/2011 11:43'!
test0020BasicConfigurationLoad
	"Second test:
		- load configuration version dkh.1
		- verify that config info added to root
		- validate that all of the data structures are correct .... based on the configuration. "
	| configClassName configClass configInfo baselines versions info packages text |
	configClassName := #ConfigurationOfMBFooTests.
	self assert: (Smalltalk at: configClassName ifAbsent: []) isNil.
	gofer version: 'ConfigurationOfMBFooTests-dkh.1'.
	gofer load.
	self assert: (configClass := Smalltalk at: configClassName ifAbsent: []) notNil.
	"configuration"
	configInfo := configurationRoot configurationInfoFor: configClass.
	self assert: configInfo notNil.  
	self assert: configInfo configurationClass == configClass.
	self assert: configInfo isDirty not.
	self assert: configInfo currentVersion isNil.
	self assert: configInfo name = configClassName asString.
	self assert: configInfo validate isEmpty.
	self assert: configInfo projects isEmpty.
	self assert: configInfo packages isEmpty.
	self assert: configInfo groups isEmpty.
	self assert: configInfo printString = 'MBFooTests (dkh.1)'.
	text := configInfo asStringOrText.
	self assert: text isString.
	self assert: text  = 'MBFooTests (dkh.1)'.
	baselines := configInfo baselines.
	self assert: baselines size = 1.
	"baseline"
	info := baselines first.
	self assert: info version blessing == #baseline.
	self assert: info version versionString = '1.0-baseline'.
	self assert: info isDirty not.
	self assert: info validate isEmpty.
	self assert: info projects isEmpty.
	self assert: info groups isEmpty.
	packages := info packages.
	self assert: packages size = 1.
	info := packages first.
	self assert: info isDirty not.
	self assert: info packageName = 'MBFooTests'.
	self assert: (info spec isKindOf: MetacelloPackageSpec). 
	self assert: info spec file = 'MBFooTests'. 
	versions := configInfo versions.
	self assert: versions size = 1.
	"version"
	info := versions first.
	self assert: info version blessing == #release.
	self assert: info version versionString = '1.0'.
	self assert: info isDirty not.
	self assert: info validate isEmpty.
	self assert: info projects isEmpty.
	self assert: info groups isEmpty.
	packages := info packages.
	self assert: packages size = 1.
	info := packages first.
	self assert: info isDirty not.
	self assert: info packageName = 'MBFooTests'.
	self assert: (info spec isKindOf: MetacelloPackageSpec). 
	self assert: info spec file = 'MBFooTests-dkh.1'. 
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 4/5/2011 15:48'!
test0021ConfigurationInfoCreated
	| createdValuable configClassName configInfoCreated configInfoChanged changedValuable configInfoDeleted deletedValuable |
	configInfoDeleted := configInfoChanged := configInfoCreated := false.
	createdValuable := [ :ann | configInfoCreated := true ].
	changedValuable := [ :ann | configInfoChanged := true ].
	deletedValuable := [ :ann | configInfoDeleted := true ].
	[ 
		configurationRoot announcer on: MBConfigurationInfoCreated do: createdValuable.
		configurationRoot announcer on: MBConfigurationInfoChanged do: changedValuable.
		configurationRoot announcer on: MBConfigurationInfoDeleted do: deletedValuable.
		configClassName := #ConfigurationOfMBFooTests.

		"load configuration"
		gofer version: 'ConfigurationOfMBFooTests-dkh.1'.
		gofer load.

		self assert: configInfoCreated.
		self assert: configInfoChanged.
		self deny: configInfoDeleted.
	 ] 
			ensure: [ configurationRoot announcer 
					unsubscribe: createdValuable;
					unsubscribe: deletedValuable;
					unsubscribe: changedValuable   ].
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 4/5/2011 16:47'!
test0030BasicVersionLoad
	"Third test: 
		- load configuration version dkh.1
		- verfy that the target data structures are as expected
		- load version 1.0
		- check that that expected changes to the data structures occur ... in this case that the package is loaded"
	
	| configClass configClassName configInfo versions versionInfo packages packageInfo text x |
	gofer version: 'ConfigurationOfMBFooTests-dkh.1'.
	gofer load.
	configClassName := #ConfigurationOfMBFooTests.
	self assert: (configClass := Smalltalk at: configClassName ifAbsent: []) notNil.
	configInfo := configurationRoot configurationInfoFor: configClass.
	self assert: configInfo printString = 'MBFooTests (dkh.1)'.
	text := configInfo asStringOrText.
	self assert: text isString.
	self assert: text  = 'MBFooTests (dkh.1)'.
	versions := configInfo versions.
	self assert: versions size = 1.
	versionInfo := versions first.
	packages := versionInfo packages.
	self assert: packages size = 1.
	packageInfo := packages first.
	self assert: packageInfo workingCopy isNil.
	self assert: packageInfo printString = 'MBFooTests ---'.
	text := packageInfo asStringOrText.
	self assert: text isString.
	self assert: text  = 'MBFooTests ---'.

	"load version 1.0"
	((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.0') load.
	self assert: configInfo printString = 'MBFooTests 1.0 (dkh.1)'.
	self assert: configInfo currentVersion versionString = '1.0'. 
	self assert: configInfo printString = 'MBFooTests 1.0 (dkh.1)'.
	text := configInfo asStringOrText.
	self assert: text isString.
	self assert: text  = 'MBFooTests 1.0 (dkh.1)'.
	versions := configInfo versions.
	self assert: versions size = 1.
	"reacquire the packageInfo instance, since the old instance is not valid"
	versionInfo := versions first.
	packages := versionInfo packages.
	self assert: packages size = 1.
	packageInfo := packages first.
	self assert: packageInfo workingCopy notNil.
	self assert: packageInfo printString = 'MBFooTests-dkh.1'.
	text := packageInfo asStringOrText.
	self assert: text isString.
	self assert: text  = 'MBFooTests-dkh.1'.
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 4/5/2011 15:51'!
test0031ConfigurationInfoChanged
	"If you don't touch the currentVersion of a configurationInfo, then no changed event is signaled on load."
	| createdValuable configClassName configInfoCreated configInfoChanged changedValuable configInfoDeleted deletedValuable |
	configInfoDeleted := configInfoChanged := configInfoCreated := false.
	createdValuable := [ :ann | configInfoCreated := true ].
	changedValuable := [ :ann | configInfoChanged := true ].
	deletedValuable := [ :ann | configInfoDeleted := true ].
	[ 
		configurationRoot announcer on: MBConfigurationInfoCreated do: createdValuable.
		configurationRoot announcer on: MBConfigurationInfoChanged do: changedValuable.
		configurationRoot announcer on: MBConfigurationInfoDeleted do: deletedValuable.

		"load configuration"
		configClassName := #ConfigurationOfMBFooTests.
		gofer version: 'ConfigurationOfMBFooTests-dkh.1'.
		gofer load.

		self assert: configInfoCreated.
		self assert: configInfoChanged.
		self deny: configInfoDeleted.
		configInfoDeleted := configInfoChanged := configInfoCreated := false.

		"load 1.0"
		((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.0') load.

		self deny: configInfoCreated.
		self assert: configInfoChanged.
		self deny: configInfoDeleted.
	 ] 
			ensure: [ configurationRoot announcer 
					unsubscribe: createdValuable;
					unsubscribe: deletedValuable;
					unsubscribe: changedValuable   ].
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 3/10/2011 15:56'!
test0032InfoListChanged

	| infoListChanged changedValuable |
	infoListChanged := false.
	changedValuable := [ :ann | infoListChanged := true ].
	[ 
		configurationRoot announcer on: MBInfoListChanged do: changedValuable.

		"load configuration"
		gofer version: 'ConfigurationOfMBFooTests-dkh.1'.
		gofer load.

		self deny: infoListChanged.
		infoListChanged := false.

		"load 1.0"
		((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.0') load.

		self deny: infoListChanged.
	 ] 
			ensure: [ configurationRoot announcer unsubscribe: changedValuable   ].
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 4/5/2011 16:48'!
test0040BasicVersionLoad
	"Fourth test:
	 	- load configuration dkh.1
		- send currentVersion to configInfo ... which record currentVersion
		- load version 1.0 and currentVersion should be updated to reflect fact that pacakges loaded."
	| configClass configClassName configInfo |
	gofer version: 'ConfigurationOfMBFooTests-dkh.1'.
	gofer load.
	configClassName := #ConfigurationOfMBFooTests.
	self assert: (configClass := Smalltalk at: configClassName ifAbsent: []) notNil.
	configInfo := configurationRoot configurationInfoFor: configClass.
	self assert: configInfo printString = 'MBFooTests (dkh.1)'.
	self assert: configInfo currentVersion isNil.

	"load version 1.0"
	((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.0') load.
	self assert: configInfo printString = 'MBFooTests 1.0 (dkh.1)'.
	self assert: configInfo currentVersion versionString = '1.0'. 
	self assert: configInfo printString = 'MBFooTests 1.0 (dkh.1)'.
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 3/10/2011 09:50'!
test0050BasicVersionLoad
	"Fifth test:
	 	- load configuration dkh.2(no events when loading version 1.1!!)
		- send currentVersion to configInfo ... which record currentVersion
		- load version 1.0 and currentVersion should be updated to reflect fact that pacakges loaded.
		- load version 1.1 and verify"
	| configClass configClassName configInfo |
	gofer version: 'ConfigurationOfMBFooTests-dkh.2'.
	gofer load.
	configClassName := #ConfigurationOfMBFooTests.
	self assert: (configClass := Smalltalk at: configClassName ifAbsent: []) notNil.
	configInfo := configurationRoot configurationInfoFor: configClass.
	self assert: configInfo printString = 'MBFooTests'.
	self assert: configInfo currentVersion isNil.

	"load version 1.0"
	((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.0') load.
	self assert: configInfo printString = 'MBFooTests'.
	self assert: configInfo currentVersion versionString = '1.0'.
	self assert: configInfo printString = 'MBFooTests [1.0]'.

	"load version 1.1"
	((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.1')  load.
	self flag: '...NOTE dkh.2 is identical to dkh.1and no events generated on load'.
	self assert: configInfo printString = 'MBFooTests [1.1]'.
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 4/5/2011 16:48'!
test0060BasicVersionLoad
	"Sixth test:
	 	- load configuration dkh.3
		- send currentVersion to configInfo ... which record currentVersion
		- load version 1.0 and currentVersion should be updated to reflect fact that pacakges loaded.
		- load version 1.2 and verify"
	| configClass configClassName configInfo |
	gofer version: 'ConfigurationOfMBFooTests-dkh.3'.
	gofer load.
	configClassName := #ConfigurationOfMBFooTests.
	self assert: (configClass := Smalltalk at: configClassName ifAbsent: []) notNil.
	configInfo := configurationRoot configurationInfoFor: configClass.
	self assert: configInfo printString = 'MBFooTests (dkh.3)'.
	self assert: configInfo currentVersion isNil.

	"load version 1.0"
	((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.0') load.
	self assert: configInfo printString = 'MBFooTests 1.0 (dkh.3)'.
	self assert: configInfo currentVersion versionString = '1.0'.
	self assert: configInfo printString = 'MBFooTests 1.0 (dkh.3)'.


	"load version 1.2"
	((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.2')  load.
	self assert: configInfo printString = 'MBFooTests 1.2 (dkh.3)'.
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 4/5/2011 15:52'!
test0061ConfigurationInfoChanged
	"Touch the currentVersion of a configurationInfo, expect a changed event on load"
	| createdValuable configClassName configInfoCreated configInfoChanged changedValuable configInfoDeleted deletedValuable configInfo configClass |
	configInfoDeleted := configInfoChanged := configInfoCreated := false.
	createdValuable := [ :ann | configInfoCreated := true ].
	changedValuable := [ :ann | configInfoChanged := true ].
	deletedValuable := [ :ann | configInfoDeleted := true ].
	[ 
		configurationRoot announcer on: MBConfigurationInfoCreated do: createdValuable.
		configurationRoot announcer on: MBConfigurationInfoChanged do: changedValuable.
		configurationRoot announcer on: MBConfigurationInfoDeleted do: deletedValuable.

		"load configuration"
		configClassName := #ConfigurationOfMBFooTests.
		gofer version: 'ConfigurationOfMBFooTests-dkh.3'.
		gofer load.

		self assert: configInfoCreated.
		self assert: configInfoChanged.
		self deny: configInfoDeleted.
		configInfoDeleted := configInfoChanged := configInfoCreated := false.

		configClassName := #ConfigurationOfMBFooTests.
		configClass := Smalltalk at: configClassName ifAbsent: [].
		configInfo := configurationRoot configurationInfoFor: configClass.

		"load 1.0"
		((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.0') load.

		self deny: configInfoCreated.
		self assert: configInfoChanged.
		self deny: configInfoDeleted.
		configInfoDeleted := configInfoChanged := configInfoCreated := false.

		self assert: configInfo currentVersion versionString = '1.0'.
		configInfo packages. "prime the pump"

		"load 1.2"
		((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.2') load.

		self deny: configInfoCreated.
		self assert: configInfoChanged.
		self deny: configInfoDeleted.
	 ] 
			ensure: [ configurationRoot announcer 
					unsubscribe: createdValuable;
					unsubscribe: deletedValuable;
					unsubscribe: changedValuable   ].
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 3/10/2011 16:00'!
test0062InfoListChanged
	| infoListChanged changedValuable configClassName configClass configInfo |
	infoListChanged := false.
	changedValuable := [ :ann | infoListChanged := true ].
	[ 
		configurationRoot announcer on: MBInfoListChanged do: changedValuable.

		"load configuration"
		configClassName := #ConfigurationOfMBFooTests.
		gofer version: 'ConfigurationOfMBFooTests-dkh.3'.
		gofer load.

		self deny: infoListChanged.
		infoListChanged := false.

		configClassName := #ConfigurationOfMBFooTests.
		configClass := Smalltalk at: configClassName ifAbsent: [].
		configInfo := configurationRoot configurationInfoFor: configClass.

		"load 1.0"
		((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.0') load.

		self deny: infoListChanged.
		infoListChanged := false.

		self assert: configInfo currentVersion versionString = '1.0'.
		configInfo infoList. "prime the pump"

		"load 1.2"
		((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.2') load.

		self assert: infoListChanged.
	 ] 
			ensure: [ configurationRoot announcer unsubscribe: changedValuable   ].
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 4/5/2011 16:49'!
test0070BasicVersionLoad
	"Seventh test:
	 	- load configuration dkh.3
		- load version 1.0.
		- validate package, baselines and versions state
		- load version 1.2
		- validate new package, baselines and versions state"
	| configClass configClassName configInfo expected infos |
	gofer version: 'ConfigurationOfMBFooTests-dkh.3'.
	gofer load.
	configClassName := #ConfigurationOfMBFooTests.
	self assert: (configClass := Smalltalk at: configClassName ifAbsent: []) notNil.
	configInfo := configurationRoot configurationInfoFor: configClass.
	self assert: configInfo printString = 'MBFooTests (dkh.3)'.
	self assert: configInfo currentVersion isNil.

	"load version 1.0"
	((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.0') load.
	self assert: configInfo printString = 'MBFooTests 1.0 (dkh.3)'.
	self assert: configInfo currentVersion versionString = '1.0'.
	self assert: configInfo printString = 'MBFooTests 1.0 (dkh.3)'.
	"baselines"
	infos := configInfo baselines.
	self assert: infos size = 1.
	expected := #('1.0-baseline #bleedingEdge').
	1 to: infos size do: [:index | | info |
		info := infos at: index.
		self assert: info printString = (expected at: index)].
	"versions"
	infos := configInfo versions.
	self assert: infos size = 3.
	expected := #('1.2' '1.1' ' @ 1.0 #stable').
	1 to: infos size do: [:index | | info |
		info := infos at: index.
		self assert: info printString = (expected at: index)].
	"packages"
	infos := configInfo packages.
	self assert: infos size = 1.
	expected := #('MBFooTests-dkh.1').
	1 to: infos size do: [:index | | info |
		info := infos at: index.
		self assert: info printString = (expected at: index)].

	"load version 1.2"
	((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.2')  load.
	self assert: configInfo printString = 'MBFooTests 1.2 (dkh.3)'.
	"baselines"
	infos := configInfo baselines.
	self assert: infos size = 1.
	expected := #('1.0-baseline #bleedingEdge').
	1 to: infos size do: [:index | | info |
		info := infos at: index.
		self assert: info printString = (expected at: index)].
	"versions"
	infos := configInfo versions.
	self assert: infos size = 3.
	expected := #(' @ 1.2' '1.1' '1.0 #stable').
	1 to: infos size do: [:index | | info |
		info := infos at: index.
		self assert: info printString = (expected at: index)].
	"packages"
	infos := configInfo packages.
	self assert: infos size = 1.
	expected := #('MBFooTests-dkh.3').
	1 to: infos size do: [:index | | info |
		info := infos at: index.
		self assert: info printString = (expected at: index)].
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 4/5/2011 16:49'!
test0080BasicVersionLoad
	"Eighth test:
	 	- load configuration dkh.3
		- load version 1.2
		- validate package and configInfo state
		- edit class and validate"
	| configClass configClassName configInfo expected infos x |
	gofer version: 'ConfigurationOfMBFooTests-dkh.3'.
	gofer load.
	configClassName := #ConfigurationOfMBFooTests.
	self assert: (configClass := Smalltalk at: configClassName ifAbsent: []) notNil.
	configInfo := configurationRoot configurationInfoFor: configClass.
	self assert: configInfo printString = 'MBFooTests (dkh.3)'.
	self assert: configInfo currentVersion isNil.

	"load version 1.2"
	((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.2')  load.
	self assert: configInfo printString = 'MBFooTests 1.2 (dkh.3)'.
	self assert: configInfo currentVersion versionString = '1.2'.
	self assert: configInfo printString = 'MBFooTests 1.2 (dkh.3)'.
	self assert: configInfo asStringOrText isString.
	"versions"
	infos := configInfo versions.
	self assert: infos size = 3.
	expected := #(' @ 1.2' '1.1' '1.0 #stable').
	1 to: infos size do: [:index | | info |
		info := infos at: index.
		self assert: info printString = (expected at: index)].
	"packages"
	infos := configInfo packages.
	self assert: infos size = 1.
	expected := #('MBFooTests-dkh.3').
	1 to: infos size do: [:index | | info |
		info := infos at: index.
		self assert: info printString = (expected at: index).
		self assert: info asStringOrText isString ].
	
	"modify class in MBFooTests project"
	(Smalltalk at: #MBFooTestA)
		compile: 'bar ^self' classified: 'mod'.

	self assert: (x := configInfo printString) = '* MBFooTests 1.2 (dkh.3)'.
	self assert: configInfo asStringOrText isText.
	"packages"
	infos := configInfo packages.
	self assert: infos size = 1.
	expected := #('* MBFooTests-dkh.3').
	1 to: infos size do: [:index | | info |
		info := infos at: index.
		self assert: info printString = (expected at: index).
		self assert: info asStringOrText isText].
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 4/5/2011 16:50'!
test0081BasicVersionLoad
	"8.1:
	 	- load configuration dkh.3
		- load version 1.2
		- validate package and configInfo state
		- edit class
		- validate #recalculate variant for currentVersion"
	| configClass configClassName configInfo expected infos|
	gofer version: 'ConfigurationOfMBFooTests-dkh.3'.
	gofer load.
	configClassName := #ConfigurationOfMBFooTests.
	self assert: (configClass := Smalltalk at: configClassName ifAbsent: []) notNil.
	configInfo := configurationRoot configurationInfoFor: configClass.
	self assert: configInfo printString = 'MBFooTests (dkh.3)'.
	self assert: configInfo currentVersion isNil.
	self assert: configInfo asStringOrText  = 'MBFooTests (dkh.3)'.
 
	"load version 1.2"
	((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.2')  load.
	self assert: configInfo printString = 'MBFooTests 1.2 (dkh.3)'. 
	self assert: configInfo currentVersion versionString = '1.2'. 
	self assert: configInfo printString = 'MBFooTests 1.2 (dkh.3)'.
	self assert: configInfo asStringOrText  = 'MBFooTests 1.2 (dkh.3)'.
	
	"modify class in MBFooTests project"
	(Smalltalk at: #MBFooTestA)
		compile: 'bar ^self' classified: 'mod'.

	self assert: configInfo printString = '* MBFooTests 1.2 (dkh.3)'. 
	self assert: configInfo asStringOrText  = '* MBFooTests 1.2 (dkh.3)'.
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 4/5/2011 15:52'!
test0082ConfigurationInfoChanged

	| configInfoDeleted configInfoChanged configInfoCreated createdValuable changedValuable deletedValuable configClassName configClass configInfo |
	configInfoDeleted := configInfoChanged := configInfoCreated := false.
	createdValuable := [ :ann | configInfoCreated := true ].
	changedValuable := [ :ann | configInfoChanged := true ].
	deletedValuable := [ :ann | configInfoDeleted := true ].
	[ 
		configurationRoot announcer on: MBConfigurationInfoCreated do: createdValuable.
		configurationRoot announcer on: MBConfigurationInfoChanged do: changedValuable.
		configurationRoot announcer on: MBConfigurationInfoDeleted do: deletedValuable.

		"load configuration"
		gofer version: 'ConfigurationOfMBFooTests-dkh.3'.
		gofer load.

		self assert: configInfoCreated.
		self assert: configInfoChanged.
		self deny: configInfoDeleted.
		configInfoDeleted := configInfoChanged := configInfoCreated := false.

		configClassName := #ConfigurationOfMBFooTests.
		configClass := Smalltalk at: configClassName ifAbsent: [].
		configInfo := configurationRoot configurationInfoFor: configClass.

		"load version 1.2"
		((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.2')  load.

		self deny: configInfoCreated.
		self assert: configInfoChanged.
		self deny: configInfoDeleted.
		configInfoDeleted := configInfoChanged := configInfoCreated := false.

		self assert: configInfo currentVersion versionString = '1.2'.
		configInfo packages. "prime the pump"

		"modify class in MBFooTests project"
		(Smalltalk at: #MBFooTestA)
			compile: 'bar ^self' classified: 'mod'.

		self deny: configInfoCreated.
		self assert: configInfoChanged.
		self deny: configInfoDeleted.
		configInfoDeleted := configInfoChanged := configInfoCreated := false.
	 ] 
			ensure: [ configurationRoot announcer 
					unsubscribe: createdValuable;
					unsubscribe: deletedValuable;
					unsubscribe: changedValuable   ].
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 3/10/2011 16:03'!
test0083InfoListChanged
	| infoListChanged changedValuable configClassName configClass configInfo |
	infoListChanged := false.
	changedValuable := [ :ann | infoListChanged := true ].
	[ 
		configurationRoot announcer on: MBInfoListChanged do: changedValuable.

		"load configuration"
		configClassName := #ConfigurationOfMBFooTests.
		gofer version: 'ConfigurationOfMBFooTests-dkh.3'.
		gofer load.

		self deny: infoListChanged.
		infoListChanged := false.

		configClassName := #ConfigurationOfMBFooTests.
		configClass := Smalltalk at: configClassName ifAbsent: [].
		configInfo := configurationRoot configurationInfoFor: configClass.

		"load 1.2"
		((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.2') load.

		self deny: infoListChanged.
		infoListChanged := false.

		self assert: configInfo currentVersion versionString = '1.2'.
		configInfo infoList. "prime the pump"

		"modify class in MBFooTests project"
		(Smalltalk at: #MBFooTestA)
			compile: 'bar ^self' classified: 'mod'.

		self assert: infoListChanged.
	 ] 
			ensure: [ configurationRoot announcer unsubscribe: changedValuable   ].
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 4/5/2011 16:54'!
test0090BasicVersionLoad
	"9:
	 	- load configuration dkh.3
		- load version 1.2
		- edit class
		- verify state
		- revert MBFooTests-dkh.3
		- validate"
	| configClass configClassName configInfo expected infos revertGofer |
	gofer version: 'ConfigurationOfMBFooTests-dkh.3'.
	gofer load.
	configClassName := #ConfigurationOfMBFooTests.
	self assert: (configClass := Smalltalk at: configClassName ifAbsent: []) notNil.
	configInfo := configurationRoot configurationInfoFor: configClass.
	self assert: configInfo printString = 'MBFooTests (dkh.3)'.
	self assert: configInfo currentVersion isNil.

	"load version 1.2"
	((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.2')  load.
	self assert: (configInfo printString) = 'MBFooTests 1.2 (dkh.3)'.
	self assert: configInfo currentVersion versionString = '1.2'.

	"modify class in MBFooTests project"
	(Smalltalk at: #MBFooTestA)
		compile: 'bar ^self' classified: 'mod'.

	self assert: (configInfo printString) = '* MBFooTests 1.2 (dkh.3)'.
	self assert: configInfo asStringOrText isText.
	"packages"
	infos := configInfo packages.
	self assert: infos size = 1.
	expected := #('* MBFooTests-dkh.3').
	1 to: infos size do: [:index | | info |
		info := infos at: index.
		self assert: info printString = (expected at: index).
		self assert: info asStringOrText isText].

	"revert MBFooTests-dkh.3"
	revertGofer := Gofer new.
	revertGofer disablePackageCache.
	gofer repositories do: [ :repo | revertGofer repository: repo ].
	revertGofer version: 'MBFooTests-dkh.3'.
	[ revertGofer load ] on: Warning do: [:ex | ex resume ].

	self assert: (configInfo printString) = 'MBFooTests 1.2 (dkh.3)'.
	self assert: configInfo asStringOrText isString.
	"packages"
	infos := configInfo packages.
	self assert: infos size = 1.
	expected := #('MBFooTests-dkh.3').
	1 to: infos size do: [:index | | info |
		info := infos at: index.
		self assert: info printString = (expected at: index).
		self assert: info asStringOrText isString].
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 4/5/2011 16:54'!
test0091PackageMismatch
	"
	 	- load configuration dkh.3
		- load version 1.2
		- validate package printString
		- load MBFooTests-dkh.4
		- validate package printString
	"
	| configClass configClassName configInfo expected infos revertGofer |
	gofer version: 'ConfigurationOfMBFooTests-dkh.3'.
	gofer load.
	configClassName := #ConfigurationOfMBFooTests.
	configClass := Smalltalk at: configClassName ifAbsent: [].
	configInfo := configurationRoot configurationInfoFor: configClass.

	"load version 1.1"
	((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.2')  load.
	self assert: (configInfo printString) = 'MBFooTests 1.2 (dkh.3)'.
	self assert: configInfo currentVersion versionString = '1.2'.

	"packages"
	infos := configInfo packages.
	self assert: infos size = 1.
	expected := #('MBFooTests-dkh.3').
	1 to: infos size do: [:index | | info |
		info := infos at: index.
		self assert: info printString = (expected at: index).
		self assert: info asStringOrText isString].

	"load MBFooTests-dkh.4"
	gofer version: 'MBFooTests-dkh.4'.
	gofer load.

	"packages"
	infos := configInfo packages.
	self assert: infos size = 1.
	expected := #('MBFooTests-dkh.3 [dkh.4]').
	1 to: infos size do: [:index | | info |
		info := infos at: index.
		self assert: info printString = (expected at: index).
		self assert: info asStringOrText isText].
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 4/5/2011 13:16'!
test0100BasicConfigurationUnload
	"10:
	 	- load configuration dkh.3
		- unload configuration"

	"load dkh.3"
	| configClassName configClass configInfo |
	gofer version: 'ConfigurationOfMBFooTests-dkh.3'.
	gofer load.

	configClassName := #ConfigurationOfMBFooTests.
	self assert: (configClass := Smalltalk at: configClassName ifAbsent: []) notNil.
	configInfo := configurationRoot configurationInfoFor: configClass.
	self assert: configInfo printString = 'MBFooTests (dkh.3)'.

	"unload dkh.3"
	gofer unload.

	self assert: (configurationRoot configurations includes: configInfo) not.
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 4/5/2011 15:52'!
test0101ConfigurationInfoDeleted
	| createdValuable configClassName configInfoCreated configInfoChanged changedValuable configInfoDeleted deletedValuable configClass configInfo |
	configInfoDeleted := configInfoChanged := configInfoCreated := false.
	createdValuable := [ :ann | configInfoCreated := true ].
	changedValuable := [ :ann | configInfoChanged := true ].
	deletedValuable := [ :ann | configInfoDeleted := true ].
	[ 
		configurationRoot announcer on: MBConfigurationInfoCreated do: createdValuable.
		configurationRoot announcer on: MBConfigurationInfoChanged do: changedValuable.
		configurationRoot announcer on: MBConfigurationInfoDeleted do: deletedValuable.
		configClassName := #ConfigurationOfMBFooTests.

		"load configuration"
		gofer version: 'ConfigurationOfMBFooTests-dkh.1'.
		gofer load.

		self assert: configInfoCreated.
		self assert: configInfoChanged.
		self deny: configInfoDeleted.
		configInfoDeleted := configInfoChanged := configInfoCreated := false.

		configClassName := #ConfigurationOfMBFooTests.
		self assert: (configClass := Smalltalk at: configClassName ifAbsent: []) notNil.
		configInfo := configurationRoot configurationInfoFor: configClass.
		self assert: configInfo printString = 'MBFooTests (dkh.1)'.

		"unload dkh.3"
		gofer unload.

		self deny: configInfoCreated.
		self assert: configInfoChanged.
		self assert: configInfoDeleted.
		configInfoDeleted := configInfoChanged := configInfoCreated := false.
		self assert: (configurationRoot configurations includes: configInfo) not.

	 ] 
			ensure: [ configurationRoot announcer 
					unsubscribe: createdValuable;
					unsubscribe: deletedValuable;
					unsubscribe: changedValuable   ].
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 4/5/2011 16:54'!
test0110BasicPackageUnload

	"load dkh.3"
	| configClassName configClass configInfo unloadGofer infos |
	gofer version: 'ConfigurationOfMBFooTests-dkh.3'.
	gofer load.

	configClassName := #ConfigurationOfMBFooTests.
	self assert: (configClass := Smalltalk at: configClassName ifAbsent: []) notNil.
	configInfo := configurationRoot configurationInfoFor: configClass.
	self assert: configInfo printString = 'MBFooTests (dkh.3)'.

	"load version 1.2"
	((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.2')  load.

	"unload MBFooTests-dkh.3"
	unloadGofer := Gofer new.
	unloadGofer disablePackageCache.
	unloadGofer version: 'MBFooTests-dkh.3'.
	[ unloadGofer unload ] on: Warning do: [:ex | ex resume ].

	self assert: (configInfo printString) = 'MBFooTests (dkh.3)'.
	self assert: configInfo asStringOrText isString.
	"packages"
	infos := configInfo packages.
	self assert: infos size = 0.
! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 3/10/2011 16:51'!
test0111InfoListChanged
	| infoListChanged changedValuable configClassName configClass configInfo unloadGofer |
	infoListChanged := false.
	changedValuable := [ :ann | infoListChanged := true ].
	[ 
		configurationRoot announcer on: MBInfoListChanged do: changedValuable.

		"load configuration"
		gofer version: 'ConfigurationOfMBFooTests-dkh.3'.
		gofer load.

		self deny: infoListChanged.
		infoListChanged := false.

		configClassName := #ConfigurationOfMBFooTests.
		configClass := Smalltalk at: configClassName ifAbsent: [].
		configInfo := configurationRoot configurationInfoFor: configClass.

		"load version 1.2"
		((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.2')  load.

		self deny: infoListChanged.
		infoListChanged := false.

		self assert: configInfo currentVersion versionString = '1.2'.
		configInfo infoList. "prime the pump"

		"unload MBFooTests-dkh.3"
		unloadGofer := Gofer new.
		unloadGofer disablePackageCache.
		unloadGofer version: 'MBFooTests-dkh.3'.
		[ unloadGofer unload ] on: Warning do: [:ex | ex resume ].

		self assert: infoListChanged.
	 ] 
			ensure: [ configurationRoot announcer unsubscribe: changedValuable   ].

! !

!MBConfigurationRootTest methodsFor: 'tests' stamp: 'dkh 4/5/2011 19:44'!
test0120ConfigPackageSave
	"Issue 125 test
	 	- load configuration dkh.3
		- load version 1.2
		- modify configuration and validate
		- save configuration package and validate"
	| configClass configClassName configInfo expected infos suggestedName signature |
	"load configuration dkh.3"
	gofer version: 'ConfigurationOfMBFooTests-dkh.3'.
	gofer load.
	configClassName := #ConfigurationOfMBFooTests.
	self assert: (configClass := Smalltalk at: configClassName ifAbsent: []) notNil.
	configInfo := configurationRoot configurationInfoFor: configClass.

	"load version 1.2"
	((Smalltalk at: #ConfigurationOfMBFooTests) project version: '1.2')  load.
	self assert: configInfo workingCopy notNil. 
	
	self assert: configInfo printString = 'MBFooTests 1.2 (dkh.3)'.
	self assert: configInfo currentVersion versionString = '1.2'.
	self assert: configInfo printString = 'MBFooTests 1.2 (dkh.3)'.
	self assert: configInfo asStringOrText isString.
	
	"modify class in ConfigurationOfMBFooTests class"
	(Smalltalk at: #ConfigurationOfMBFooTests)
		compile: 'bar ^self' classified: 'mod'.

	self assert: configInfo printString = '* MBFooTests 1.2 (dkh.3)'.
	self assert: configInfo asStringOrText isText.

	"save the configuraiton package"
	[ Gofer new
		disablePackageCache;
		repository: (MCDictionaryRepository new);
		package: configClassName asString;
		commit ] 
			on: MCVersionNameAndMessageRequest
			do: [:ex |  
				suggestedName := ex suggestedName.
				ex resume: { suggestedName.  'commit comment'}].

	signature := suggestedName copyAfterLast: $-.
	self assert: configInfo printString = ('MBFooTests 1.2 (', signature, ')').
	self assert: configInfo asStringOrText isString.
! !
